Status
Task lifecycle status.
Usage
StatusTracks the progression of a task from creation to completion.
Attributes
PENDING-
Task has been created but not started.
RUNNING-
Task is currently executing.
COMPLETED-
Task finished successfully.
FAILED-
Task encountered an error.
Attributes
| Name | Description |
|---|---|
| COMPLETED | Task lifecycle status. |
| FAILED | Task lifecycle status. |
| PENDING | Task lifecycle status. |
| RUNNING | Task lifecycle status. |
COMPLETED
Task lifecycle status.
COMPLETED=auto()
Tracks the progression of a task from creation to completion.
Attributes: PENDING: Task has been created but not started. RUNNING: Task is currently executing. COMPLETED: Task finished successfully. FAILED: Task encountered an error.
FAILED
Task lifecycle status.
FAILED=auto()
Tracks the progression of a task from creation to completion.
Attributes: PENDING: Task has been created but not started. RUNNING: Task is currently executing. COMPLETED: Task finished successfully. FAILED: Task encountered an error.
PENDING
Task lifecycle status.
PENDING=auto()
Tracks the progression of a task from creation to completion.
Attributes: PENDING: Task has been created but not started. RUNNING: Task is currently executing. COMPLETED: Task finished successfully. FAILED: Task encountered an error.
RUNNING
Task lifecycle status.
RUNNING=auto()
Tracks the progression of a task from creation to completion.
Attributes: PENDING: Task has been created but not started. RUNNING: Task is currently executing. COMPLETED: Task finished successfully. FAILED: Task encountered an error.